/*
 * $Id: MatchState.java 292 2006-02-28 23:30:47Z davidb $
 * 
 * Copyright (c) 2005 VeriSign. All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer. 2. Redistributions in
 * binary form must reproduce the above copyright notice, this list of
 * conditions and the following disclaimer in the documentation and/or other
 * materials provided with the distribution. 3. The name of the author may not
 * be used to endorse or promote products derived from this software without
 * specific prior written permission.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN
 * NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF
 * LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING
 * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */

package se.rfc.unbound.nsclient;

import org.xbill.DNS.Message;
import org.xbill.DNS.Record;

import se.rfc.unbound.Host;
import se.rfc.unbound.Request;

public class MatchState
{
  // Match parameters.
  private int     mRequestID;
  private Record  mRequestQuestion;
  private Host    mTarget;

  // per query state.
  private long    mTimeoutDuration;
  private long    mWakeupDuration;
  private boolean mUseTCP;
  private boolean mSentWithoutEDNS;
  private long    mSentTime;

  // Just for logging purposes;
  private Message mRequestMessage;

  public MatchState()
  {
  }

  public void setRequestInfo(Request request)
  {
    mRequestID = request.getID();
    mRequestQuestion = request.getQuestion();
    mTarget = request.getTarget();
  }

  /**
   * @return Returns the requestID.
   */
  public int getRequestID()
  {
    return mRequestID;
  }

  /**
   * @return Returns the requestQuestion.
   */
  public Record getRequestQuestion()
  {
    return mRequestQuestion;
  }

  /**
   * @return Returns the target.
   */
  public Host getTarget()
  {
    return mTarget;
  }

  /**
   * @return Returns the sentWithoutEDNS.
   */
  public boolean getSentWithoutEDNS()
  {
    return mSentWithoutEDNS;
  }

  /**
   * @param sentWithoutEDNS The sentWithoutEDNS to set.
   */
  public void setSentWithoutEDNS(boolean sentWithoutEDNS)
  {
    mSentWithoutEDNS = sentWithoutEDNS;
  }

  /**
   * @return Returns the useTCP.
   */
  public boolean getUseTCP()
  {
    return mUseTCP;
  }

  /**
   * @param useTCP The useTCP to set.
   */
  public void setUseTCP(boolean useTCP)
  {
    mUseTCP = useTCP;
  }

  /**
   * @return Returns the timeoutDuration.
   */
  public long getTimeoutDuration()
  {
    return mTimeoutDuration;
  }

  /**
   * @param timeoutDuration The timeoutDuration to set.
   */
  public void setTimeoutDuration(long timeoutDuration)
  {
    mTimeoutDuration = timeoutDuration;
  }

  /**
   * @return Returns the sentTime.
   */
  public long getSentTime()
  {
    return mSentTime;
  }

  /**
   * @param sentTime The sentTime to set.
   */
  public void setSentTime(long sentTime)
  {
    mSentTime = sentTime;
  }

  /**
   * @return Returns the requestMessage.
   */
  public Message getRequestMessage()
  {
    return mRequestMessage;
  }

  /**
   * @param requestMessage The requestMessage to set.
   */
  public void setRequestMessage(Message requestMessage)
  {
    mRequestMessage = requestMessage;
  }

  /**
   * @return Returns the wakeupDuration.
   */
  public long getWakeupDuration()
  {
    return mWakeupDuration;
  }

  /**
   * @param wakeupDuration The wakeupDuration to set.
   */
  public void setWakeupDuration(long wakeupDuration)
  {
    mWakeupDuration = wakeupDuration;
  }
}
